@@ -17,6 +17,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import ros_cdk_core
@@ -33,7 +35,7 @@ class Certificate(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "CertificateProps",
+        props: typing.Union["CertificateProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::CAS::Certificate``.
@@ -47,9 +49,22 @@ class Certificate(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["CertificateProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrCertId")
     def attr_cert_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute CertId: Certificate ID.'''
@@ -85,6 +100,22 @@ class CertificateProps:
         :param lang: Property lang: Specifies the language type for requesting and receiving messages.
         :param source_ip: Property sourceIp: Specifies the source IP address of the request.
         '''
+        if __debug__:
+            def stub(
+                *,
+                cert: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                lang: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                source_ip: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument cert", value=cert, expected_type=type_hints["cert"])
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument lang", value=lang, expected_type=type_hints["lang"])
+            check_type(argname="argument source_ip", value=source_ip, expected_type=type_hints["source_ip"])
         self._values: typing.Dict[str, typing.Any] = {
             "cert": cert,
             "key": key,
@@ -164,7 +195,7 @@ class RosCertificate(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosCertificateProps",
+        props: typing.Union["RosCertificateProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::CAS::Certificate``.
@@ -174,6 +205,19 @@ class RosCertificate(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosCertificateProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -184,15 +228,20 @@ class RosCertificate(
         '''
         :param props: -
         '''
+        if __debug__:
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrCertId")
     def attr_cert_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -200,12 +249,12 @@ class RosCertificate(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrCertId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cert")
     def cert(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -215,18 +264,30 @@ class RosCertificate(
 
     @cert.setter
     def cert(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cert", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="key")
     def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -236,9 +297,16 @@ class RosCertificate(
 
     @key.setter
     def key(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "key", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -248,9 +316,16 @@ class RosCertificate(
 
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lang")
     def lang(
         self,
@@ -265,9 +340,16 @@ class RosCertificate(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "lang", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sourceIp")
     def source_ip(
         self,
@@ -282,6 +364,13 @@ class RosCertificate(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceIp", value)
 
 
@@ -314,6 +403,22 @@ class RosCertificateProps:
         :param lang: 
         :param source_ip: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                cert: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                lang: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                source_ip: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument cert", value=cert, expected_type=type_hints["cert"])
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument lang", value=lang, expected_type=type_hints["lang"])
+            check_type(argname="argument source_ip", value=source_ip, expected_type=type_hints["source_ip"])
         self._values: typing.Dict[str, typing.Any] = {
             "cert": cert,
             "key": key,
